﻿using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.KnowledgeGraph;
using ArcGIS.Desktop.Layouts;
using ArcGIS.Desktop.Mapping;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace GithubCopilotTesting
{
  /// <summary>
  /// Represents the ComboBox
  /// </summary>
  internal class StatesComboBox : ComboBox
  {
    internal static List<String> _states = new List<String>
    {
      "Alabama", "Alaska", "Arizona", "Arkansas", "California", "Colorado", "Connecticut", "Delaware", "Florida", "Georgia",
      "Hawaii", "Idaho", "Illinois", "Indiana", "Iowa", "Kansas", "Kentucky", "Louisiana", "Maine", "Maryland",
      "Massachusetts", "Michigan", "Minnesota", "Mississippi", "Missouri", "Montana", "Nebraska", "Nevada", "New Hampshire", "New Jersey",
      "New Mexico", "New York", "North Carolina", "North Dakota", "Ohio", "Oklahoma", "Oregon", "Pennsylvania", "Rhode Island", "South Carolina",
      "South Dakota", "Tennessee", "Texas", "Utah", "Vermont", "Virginia", "Washington", "West Virginia", "Wisconsin", "Wyoming"
    };
    private bool _isInitialized;
    private FeatureLayer _nationalParksLayer;

    /// <summary>
    /// Combo Box constructor
    /// </summary>
    public StatesComboBox()
    {
      var activeMapView = MapView.Active;
      if (activeMapView == null) return;
      //Get the National Parks Feature layer from the active map
      _nationalParksLayer = activeMapView.Map?.GetLayersAsFlattenedList().OfType<FeatureLayer>().FirstOrDefault(lyr => lyr.Name == "NationalParks");
      if (_nationalParksLayer == null) return;
      UpdateCombo();
    }

    /// <summary>
    /// Updates the combo box with all the items.
    /// </summary>

    private void UpdateCombo()
    {
      // TODO – customize this method to populate the combobox with your desired items  
      if (_isInitialized)
        SelectedItem = ItemCollection.FirstOrDefault(); //set the default item in the comboBox


      if (!_isInitialized)
      {
        Clear();

        //Iterate through _states and add each state to the comboBox
        foreach (var state in _states)
        {
          Add(new ComboBoxItem(state));
        }
        _isInitialized = true;
      }


      Enabled = true; //enables the ComboBox
      SelectedItem = ItemCollection.FirstOrDefault(); //set the default item in the comboBox

    }

    /// <summary>
    /// The on comboBox selection change event. 
    /// </summary>
    /// <param name="item">The newly selected combo box item</param>
    protected override void OnSelectionChange(ComboBoxItem item)
    {
      if (item == null || string.IsNullOrEmpty(item.Text))
        return;

      // Get the selected state
      var selectedState = item.Text;

      // Create a QueryFilter with a WhereClause
      var queryFilter = new QueryFilter
      {
        WhereClause = $"State = '{selectedState}'"
      };

      // Select features in the national parks layer using the query filter and zoom to the selected features
      QueuedTask.Run(() =>
      {
        var selection = _nationalParksLayer.Select(queryFilter);
        if (selection.GetCount() > 0)
        {
          var activeMapView = MapView.Active;
          if (activeMapView == null) return;

          // Zoom to the selected features
          activeMapView.ZoomToSelected(new TimeSpan(0, 0, 3));
        }
      });
    }
  }
}
